@@ -23,13 +23,12 @@
 
 from __future__ import print_function
 
-import errno
 import io
 import os
 import tokenize
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 try:
@@ -40,6 +39,9 @@ except NameError:
 
 def format_code(source, preferred_quote="'"):
     """Return source code with quotes unified."""
+    if not source:
+        return source
+
     sio = io.StringIO(source)
     formatted = ''
     previous_line = ''
@@ -140,11 +142,12 @@ def format_file(filename, args, standard_out):
         else:
             import difflib
             diff = difflib.unified_diff(
-                io.StringIO(source).readlines(),
-                io.StringIO(formatted_source).readlines(),
+                source.splitlines(),
+                formatted_source.splitlines(),
                 'before/' + filename,
-                'after/' + filename)
-            standard_out.write(unicode().join(diff))
+                'after/' + filename,
+                lineterm='')
+            standard_out.write(unicode('\n').join(list(diff) + ['']))
 
 
 def main(argv, standard_out, standard_error):
@@ -171,13 +174,10 @@ def main(argv, standard_out, standard_error):
                 filenames += [os.path.join(root, f) for f in children
                               if f.endswith('.py') and
                               not f.startswith('.')]
-                for d in directories:
-                    if d.startswith('.'):
-                        directories.remove(d)
+                directories[:] = [d for d in directories
+                                  if not d.startswith('.')]
         else:
             try:
                 format_file(name, args=args, standard_out=standard_out)
             except IOError as exception:
-                if exception.errno == errno.EPIPE:
-                    return
-                print(exception, file=standard_error)
+                print(unicode(exception), file=standard_error)
